Documentation
¶
Index ¶
- type Logger
- type Zap
- func (z *Zap) Close() error
- func (z *Zap) Debug(format string, args ...any)
- func (z *Zap) Error(format string, args ...any)
- func (z *Zap) Fatal(format string, args ...any)
- func (z *Zap) Info(format string, args ...any)
- func (z *Zap) Panic(format string, args ...any)
- func (z *Zap) Warn(format string, args ...any)
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Logger ¶
type Logger interface {
// Debug logs a debug message.
Debug(format string, args ...any)
// Info logs an info message.
Info(format string, args ...any)
// Warn logs a warning message.
Warn(format string, args ...any)
// Error logs an error message.
Error(format string, args ...any)
// Fatal logs a fatal message.
Fatal(format string, args ...any)
// Panic logs a panic message.
Panic(format string, args ...any)
// Close flushes any buffered log entries.
Close() error
}
Logger is an interface that defines the methods for the logger.
type Zap ¶
type Zap struct {
*zap.SugaredLogger
}
Zap is a wrapper for the log interface using zap library.
Click to show internal directories.
Click to hide internal directories.